
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2022 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_DEFECTIVEPIXEL_H
#define ITALA_API_DEFECTIVEPIXEL_H

#include <cstdint>
#include <vector>
#include "Base/GCString.h"
#include "ItalaApi/Export.h"
#include "ItalaApi/ItalaDefs.h"

namespace Itala {

struct DefectivePixelData;

struct ITALA_API DefectivePixel {
  /**
   * Get the X image coordinate of the defective pixel.
   */
  uint64_t X() const;

  /**
   * Get the Y image coordinate of the defective pixel.
   */
  uint64_t Y() const;

  /**
   * Get the type of defect the pixel has.
   */
  DefectType Type() const;

  /**
   * Get the string representation of the type of defect the pixel has.
   */
  GENICAM_NAMESPACE::gcstring TypeString() const;

private:
  DefectivePixelData* op;

public:
  DefectivePixel();
  DefectivePixel(DefectivePixelData* data);
  DefectivePixel(const DefectivePixel& other);
  DefectivePixel(DefectivePixel&& other);
  DefectivePixel& operator=(const DefectivePixel& other);
  DefectivePixel& operator=(DefectivePixel&& other);
  ~DefectivePixel();
  bool operator==(const DefectivePixel& other);
  DefectivePixelData& GetOp();
};
typedef std::vector<DefectivePixel> DefectivePixelList;
}  // namespace Itala

#endif