
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2022 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_DEVICEEVENTHANDLER_H
#define ITALA_API_DEVICEEVENTHANDLER_H

#include <cstdint>

namespace Itala {
  
/**
 * Abstract for handling events coming from the device. This class must be
 * overridden by the user. This way the user-defined OnDeviceEvent method is
 * called when an event arrives.
 */
struct DeviceEventHandler {
  virtual ~DeviceEventHandler() {}

  /**
   * This pure virtual method must be overriden by the user class implementing
   * the interface. The event ID is provided to allow the user to identify
   * the event itself.
   * The device NodeMap is also automatically updated with the event data.
   */
  virtual void OnDeviceEvent(uint64_t eventId){};
};
}  // namespace Itala

#endif