
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2022 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_IDISPOSABLE_H
#define ITALA_API_IDISPOSABLE_H

#include <memory>

namespace Itala {
  
/**
 * Interface representing a disposable object, e.g. the ISystem, IDevice and
 * IImage interfaces. Disposable objects require to be disposed by calling the
 * IDisposable::Dispose method instead of the "delete" operator. This way, their
 * destruction is managed in a safe way within ItalaApi.
 */
struct IDisposable {
  /**
   * When an IDisposable object is no longer required, this method
   * MUST be called. If the instance is owned by a smart pointer, this function
   * must be used as deleter or, in general, called on destruction of the RAII owner.
   */
  virtual void Dispose() = 0;

protected:
  virtual ~IDisposable() {}
};

}  // namespace Itala

#endif