
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2022 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_TOSTRING_H
#define ITALA_API_TOSTRING_H

#include "Base/GCString.h"
#include "ItalaApi/Export.h"
#include "ItalaApi/ItalaDefs.h"

namespace Itala {

/**
 * Converts a four-byte address to a readable string representation in
 * dotted-decimal format. This function is useful for displaying IP
 * addresses, gateways and subnet masks as well.
 *
 * @return String representation of the address in dotted-decimal format
 */
ITALA_API
GenICam::gcstring AddressToString(uint32_t address);

/**
 * Converts a MAC address to a readable string representation in
 * colon-heaxadecimal format. This function is useful for displaying MAC addresses.
 *
 * @return String representation of the address in colon-heaxadecimal format
 */
ITALA_API
GenICam::gcstring MacAddressToString(uint64_t address);

/**
 * Converts an access status value to a readable string representation.
 *
 * @return String representation of the access status enumeration value
 */
ITALA_API
GenICam::gcstring AccessStatusToString(Itala::DeviceAccessStatus status);
}  // namespace Itala

#endif