
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_CATEGORY_H
#define ITALA_API_C_CATEGORY_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"

#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Get the number of features of the category (including sub-categories).
 *
 * @param[in] hNode Handle to Node instance, should be a Category node.
 * @param[out] pNumOfFeaturs Number of features.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_CategoryGetFeaturesNum(H_NODE hNode, size_t* pNumOfFeaturs);
/**
 * Get the feature node of the category (including sub-categories), given its index.
 *
 * @param[in] hNode Handle to Node instance, should be a Category node.
 * @param[in] index Index of the feature.
 * @param[out] phFeature Handle to feature Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_CategoryGetFeatureByIndex(H_NODE hNode, size_t index,
                                                      H_NODE* phFeature);

#ifdef __cplusplus
}
}
#endif

#endif