
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_ENUMENTRY_H
#define ITALA_API_C_ENUMENTRY_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Get the integer value of the enum entry.
 *
 * @param[in] hNode Handle to Node instance, should be an EnumEntry node.
 * @param[out] pValue Value of the Node.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumEntryGetValue(H_NODE hNode, int64_t* pValue);
/**
 * Get the symbolic value of the enum entry.
 *
 * @param[in] hNode Handle to Node instance, should be an EnumEntry node.
 * @param[out] symbolic Array of char, symbolic value.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumEntryGetSymbolic(H_NODE hNode, char* symbolic, size_t* pSize);
/**
 * Get the numerical value of the enum entry.
 *
 * @param[in] hNode Handle to Node instance, should be an EnumEntry node.
 * @param[out] pValue Value of the Node.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumEntryGetNumericValue(H_NODE hNode, double* pValue);
/**
 * Get the self clearing property of the enum entry.
 *
 * @param[in] hNode Handle to Node instance, should be an EnumEntry node.
 * @param[out] pIsSelfClearing Self clearing property.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumEntryIsSelfClearing(H_NODE hNode, bool* pIsSelfClearing);

#ifdef __cplusplus
}
}
#endif

#endif