
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_ENUMERATION_H
#define ITALA_API_C_ENUMERATION_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Get the number of symbolic in the enumeratinon Node.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[out] pNumOfSymbolics Number of symbolic.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetSymbolicsNum(H_NODE hNode, size_t* pNumOfSymbolics);
/**
 * Get the symbolic in the enumeratinon Node, given a specif index.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[in] index Index of the symbolic.
 * @param[out] symbolic Array of char, symbolic value.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetSymbolicByIndex(H_NODE hNode, size_t index,
                                                          char* symbolic, size_t* pSize);
/**
 * Get the number of entries in the enumeratinon Node.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[out] pNumOfEntries Number of entires.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetEntriesNum(H_NODE hNode, size_t* pNumOfEntries);
/**
 * Get the enem entry in the enumeratinon Node, given a specific index.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[in] index Index of the symbolic.
 * @param[out] phEnumEntry Handle to enum entry Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetEntryByIndex(H_NODE hNode, size_t index,
                                                       H_NODE* phEnumEntry);
/**
 * Set the value of the Node by integer.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[in] value Value to set.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationSetIntValue(H_NODE hNode, int64_t value);
/**
 * Get the integer value of the enumeration Node.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[out] pValue Value retrived.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetIntValue(H_NODE hNode, int64_t* pValue);
/**
 * Get the entry by name of the enumeration Node.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[in] name Name of the enum entry to retrive.
 * @param[out] phEnumEntry Handle to enum entry Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetEntryByName(H_NODE hNode, const char* name,
                                                      H_NODE* phEnumEntry);
/**
 * Get the enem entry in the enumeratinon Node, given the integer value of it.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[in] value Value of the enum entry to retrive.
 * @param[out] phEnumEntry Handle to enum entry Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetEntryByIntValue(H_NODE hNode, int64_t value,
                                                          H_NODE* phEnumEntry);
/**
 * Get the current enem entry in the enumeratinon Node.
 *
 * @param[in] hNode Handle to Node instance, should be an Enumeration node.
 * @param[out] phEnumEntry Handle to enum entry Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_EnumerationGetCurrentEntry(H_NODE hNode, H_NODE* phEnumEntry);

#ifdef __cplusplus
}
}
#endif

#endif