
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_FEATURESTREAMING_H
#define ITALA_API_C_FEATURESTREAMING_H

#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"

#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Save the current state of the Nodemap to a local file. The extension of the file
 * must be specified in the input string. The path of where to save the file must
 * be included in the filename.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[in] filename String containing the location, filename and extension of the file.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_SaveToFile(H_NODEMAP hNodeMap, const char* filename);
/**
 * Load the state of the Nodemap from a local file. The extension of the file
 * must be specified in the input string. The path of where it has been saved must
 * be included in the filename.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[in] filename String containing the location, filename and extension of the file.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_LoadFromFile(H_NODEMAP hNodeMap, const char* filename);

#ifdef __cplusplus
}
}
#endif

#endif