
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_GENAPICDEFS_H
#define ITALA_API_C_GENAPICDEFS_H

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Enumeration for sign value.
 */
enum _Sign {
  Signed = 0,         //!< Integer is signed
  Unsigned = 1,       //!< Integer is unsigned
  _UndefinedSign = 2  //!< Object is not yet initialized
};
/**
 * \typedef Sign
 * @see _Sign
 */
typedef int32_t Sign;
/**
 * Enumeration for access mode value.
 */
enum _AccessMode {
  NI = 0,                    //!< Not implemented
  NA = 1,                    //!< Not available
  WO = 2,                    //!< Write Only
  RO = 3,                    //!< Read Only
  RW = 4,                    //!< Read and Write
  _UndefinedAccesMode = 5,   //!< Object is not yet initialized
  _CycleDetectAccesMode = 6  //!< used internally for AccessMode cycle detection

};
/**
 * \typedef AccessMode
 * @see _AccessMode
 */
typedef int32_t AccessMode;
/**
 * Enumeration for visibility value.
 */
enum _Visibility {
  Beginner = 0,              //!< Always visible
  Expert = 1,                //!< Visible for experts or Gurus
  Guru = 2,                  //!< Visible for Gurus
  Invisible = 3,             //!< Not Visible
  _UndefinedVisibility = 99  //!< Object is not yet initialized
};
/**
 * \typedef Visibility
 * @see _Visibility
 */
typedef int32_t Visibility;
/**
 * Enumeration for caching mode value.
 */
enum _CachingMode {
  NoCache = 0,               //!< Do not use cache
  WriteThrough = 1,          //!< Write to cache and register
  WriteAround = 2,           //!< Write to register, write to cache on read
  _UndefinedCachingMode = 3  //!< Not yet initialized
};
/**
 * \typedef CachingMode
 * @see _CachingMode
 */
typedef int32_t CachingMode;
/**
 * Enumeration for representation value.
 */
enum _Representation {
  Linear = 0,       //!< Slider with linear behavior
  Logarithmic = 1,  //!< Slider with logarithmic behaviour
  Boolean = 2,      //!< Check box
  PureNumber = 3,   //!< Decimal number in an edit control
  HexNumber = 4,    //!< Hex number in an edit control
  IPV4Address = 5,  //!< IP-Address
  MACAddress = 6,   //!< MAC-Address
  _UndefindedRepresentation = 7
};
/**
 * \typedef Representation
 * @see _Representation
 */
typedef int32_t Representation;
/**
 * Enumeration for endianess value.
 */
enum _Endianess {
  BigEndian = 0,        //!< Register is big endian
  LittleEndian = 1,     //!< Register is little endian
  _UndefinedEndian = 2  //!< Object is not yet initialized
};
/**
 * \typedef Endianess
 * @see _Endianess
 */
typedef int32_t Endianess;
/**
 * Enumeration for namespace value.
 */
enum _NameSpace {
  Custom = 0,              //!< name resides in custom namespace
  Standard = 1,            //!< name resides in one of the standard namespaces
  _UndefinedNameSpace = 2  //!< Object is not yet initialized
};
/**
 * \typedef NameSpace
 * @see _NameSpace
 */
typedef int32_t NameSpace;
/**
 * Enumeration for standard namespace value.
 */
enum _StandardNameSpace {
  None = 0,                        //!< name resides in custom namespace
  GEV = 1,                         //!< name resides in GigE Vision namespace
  IIDC = 2,                        //!< name resides in 1394 IIDC namespace
  CL = 3,                          //!< name resides in camera link namespace
  USB = 4,                         //!< name resides in USB namespace
  _UndefinedStandardNameSpace = 5  //!< Object is not yet initialized
};
/**
 * \typedef StandardNameSpace
 * @see _StandardNameSpace
 */
typedef int32_t StandardNameSpace;
/**
 * Enumeration for yes/no value.
 */
enum _YesNo {
  Yes = 1,             //!< yes
  No = 0,              //!< no
  _UndefinedYesNo = 2  //!< Object is not yet initialized
};
/**
 * \typedef YesNo
 * @see _YesNo
 */
typedef int32_t YesNo;
/**
 * Enumeration for slope value.
 */
enum _Slope {
  Increasing = 0,       //!< strictly monotonous increasing
  Decreasing = 1,       //!< strictly monotonous decreasing
  Varying = 2,          //!< slope changes, e.g. at run-time
  Automatic = 3,        //!< slope is determined automatically by probing the function
  _UndefinedESlope = 4  //!< Object is not yet initialized
};
/**
 * \typedef Slope
 * @see _Slope
 */
typedef int32_t Slope;
/**
 * Enumeration for xml validation value.
 */
enum _XMLValidation {
  xvLoad = 0x00000001L,    //!< Creates a dummy node map
  xvCycles = 0x00000002L,  //!< checks for write and dependency cycles (implies xvLoad)
  xvSFNC =
      0x00000004L,  //!< checks for conformance with the standard feature naming convention (SFNC)
  xvDefault = 0x00000000L,               //!< checks performed if nothing else is said
  xvAll = 0xffffffffL,                   //!< all possible checks
  _UndefinedEXMLValidation = 0x8000000L  //!< Object is not yet initialized
};
/**
 * \typedef XMLValidation
 * @see _XMLValidation
 */
typedef int32_t XMLValidation;
/**
 * Enumeration for display notation value.
 */
enum _DisplayNotation {
  fnAutomatic = 0,   //!< the notation if either scientific or fixed depending on what is shorter
  fnFixed = 1,       //!< the notation is fixed, e.g. 123.4
  fnScientific = 2,  //!< the notation is scientific, e.g. 1.234e2
  _UndefinedEDisplayNotation = 3  //!< Object is not yet initialized
};
/**
 * \typedef DisplayNotation
 * @see _DisplayNotation
 */
typedef int32_t DisplayNotation;
/**
 * Enumeration for interface type value.
 */
enum _InterfaceType {
  intfIValue = 0,        //!< IValue interface
  intfIBase = 1,         //!< IBase interface
  intfIInteger = 2,      //!< IInteger interface
  intfIBoolean = 3,      //!< IBoolean interface
  intfICommand = 4,      //!< ICommand interface
  intfIFloat = 5,        //!< IFloat interface
  intfIString = 6,       //!< IString interface
  intfIRegister = 7,     //!< IRegister interface
  intfICategory = 8,     //!< ICategory interface
  intfIEnumeration = 9,  //!< IEnumeration interface
  intfIEnumEntry = 10,   //!< IEnumEntry interface
  intfIPort = 11         //!< IPort interface
};
/**
 * \typedef InterfaceType
 * @see _InterfaceType
 */
typedef int32_t InterfaceType;
/**
 * Enumeration for link type value.
 */
enum _LinkType {
  ctParentNodes = 0,           //!< All nodes for which this node is at least an invalidating child
  ctReadingChildren = 1,       //!< All nodes which can be read from
  ctWritingChildren = 2,       //!< All nodes which can write a value further down the node stack
  ctInvalidatingChildren = 3,  //!< All directly connected nodes which invalidate this node
  ctDependingNodes = 4,  //!< All directly or indirectly connected nodes which are invalidated by
                         //!< this nodes (i.e. which are dependent on this node)
  ctTerminalNodes = 5,   //!< All indirectly connected terminal nodes
  ctValueChangingChildren = 6  //!< All child node used to compute the value.
};
/**
 * \typedef LinkType
 * @see _LinkType
 */
typedef int32_t LinkType;
/**
 * Enumeration for increment mode value.
 */
enum _IncMode {
  noIncrement = 0,     // !> The feature has no increment
  fixedIncrement = 1,  // !> The feature has a fix increment
  listIncrement = 2    // !> The feature has a list of valid value
};
/**
 * \typedef IncMode
 * @see _IncMode
 */
typedef int32_t IncMode;
/**
 * Enumeration for input direction value.
 */
enum _InputDirection {
  idFrom = 0,  //!< Indicates a swiss knife that it is used as worker for a converter computing FROM
  idTo = 1,    //!< Indicates a swiss knife that it is used as worker for a converter computing TO
  idNone = 2   //!< SwissKnife is not used within a converter
};
/**
 * \typedef InputDirection
 * @see _InputDirection
 */
typedef int32_t InputDirection;
/**
 * Enumeration for gen api schema version value.
 */
enum _GenApiSchemaVersion { v1_0 = 1, v1_1 = 2, _Undefined = -1 };
/**
 * \typedef GenApiSchemaVersion
 * @see _GenApiSchemaVersion
 */
typedef int32_t GenApiSchemaVersion;

#ifdef __cplusplus
}
}
#endif

#endif