
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_NODEMAP_H
#define ITALA_API_C_NODEMAP_H

#include <stddef.h>
#include "Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Get a node by its name.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[in] nodeName Name of the node to retrieve.
 * @param[out] phNode Handle to Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_GetNode(H_NODEMAP hNodeMap, const char* nodeName, H_NODE* phNode);
/**
 * Get number of nodes in the nodemap.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[out] pNumNodes Number of nodes.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_GetNumNodes(H_NODEMAP hNodeMap, size_t* pNumNodes);
/**
 * Get a node handler, given the specific index.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[in] index Index of Node.
 * @param[out] phNode Handle to Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_GetNodeByIndex(H_NODEMAP hNodeMap, size_t index, H_NODE* phNode);
/**
 * Invalidate all the node of the nodemap.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_InvalidateNodes(H_NODEMAP hNodeMap);
/**
 * Get the device name that owns the nodemap.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[out] deviceName The name of the device.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_GetDeviceName(H_NODEMAP hNodeMap, char* deviceName, size_t* pSize);
/**
 * Fires nodes which have a polling time in the nodemap.
 *
 * @param[in] hNodeMap Handle to NodeMap instance.
 * @param[out] elapsedTime Elapsed time.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODEMAP_Poll(H_NODEMAP hNodeMap, int64_t elapsedTime);

#ifdef __cplusplus
}
}
#endif

#endif