
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_REGISTER_H
#define ITALA_API_C_REGISTER_H

#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"

#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Set the value of the register Node.
 *
 * @param[in] hNode Handle to Node instance, should be a register node.
 * @param[in] pBuffer Buffer with the value to set.
 * @param[in] length Length of the buffer to set.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_RegisterSet(H_NODE hNode, uint8_t* pBuffer, int64_t length);
/**
 * Get the value of the register Node.
 *
 * @param[in] hNode Handle to Node instance, should be a register node.
 * @param[out] pBuffer Buffer with the value retrived.
 * @param[in, out] length Length of the buffer to get.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_RegisterGet(H_NODE hNode, uint8_t* pBuffer, int64_t length);
/**
 * Get the length of the register Node.
 *
 * @param[in] hNode Handle to Node instance, should be a register node.
 * @param[out] pLength Buffer length retrived.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_RegisterGetLength(H_NODE hNode, int64_t* pLength);
/**
 * Get the address of the register Node.
 *
 * @param[in] hNode Handle to Node instance, should be a register node.
 * @param[out] pLength Address retrived.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_RegisterGetAddress(H_NODE hNode, int64_t* pLength);

#ifdef __cplusplus
}
}
#endif

#endif