
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_SELECTOR_H
#define ITALA_API_C_SELECTOR_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Check if the node is actually a selector Node.
 *
 * @param[in] hNode Handle to Node instance, should be a Selector node.
 * @param[out] pIsSelector Retrieves if node is selector.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_SelectorIsSelector(H_NODE hNode, bool* pIsSelector);
/**
 * Get the number of selected feature in a selector Node.
 *
 * @param[in] hNode Handle to Node instance, should be a Selector node.
 * @param[out] pNumOfFeatureSelected Number of feature selected.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_SelectorGetSelectedFeaturesNum(H_NODE hNode,
                                                           size_t* pNumOfFeatureSelected);
/**
 * Get a selected feature in a selector Node, given a specific index.
 *
 * @param[in] hNode Handle to Node instance, should be a Selector node.
 * @param[in] index Index of the valid value.
 * @param[out] phFeature Handle to feature Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_SelectorGetSelectedFeatureByIndex(H_NODE hNode, size_t index,
                                                              H_NODE* phFeature);
/**
 * Get the number of selecting feature in a selector Node.
 *
 * @param[in] hNode Handle to Node instance, should be a Selector node.
 * @param[out] pNumOfFeatureSelecting Number of feature selecting.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_SelectorGetSelectingFeaturesNum(H_NODE hNode,
                                                            size_t* pNumOfFeatureSelecting);
/**
 * Get a selecting feature in a selector Node, given a specific index.
 *
 * @param[in] hNode Handle to Node instance, should be a Selector node.
 * @param[in] index Index of the valid value.
 * @param[out] phFeature Handle to feature Node instance.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_SelectorGetSelectingFeatureByIndex(H_NODE hNode, size_t index,
                                                               H_NODE* phFeature);

#ifdef __cplusplus
}
}
#endif

#endif