
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_STRING_H
#define ITALA_API_C_STRING_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#include "ItalaApiC/ItalaGenApiCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Set the value of the node in a string Node.
 *
 * @param[in] hNode Handle to Node instance, should be a string node.
 * @param[out] pValue Value to set to the Node.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_StringSetValue(H_NODE hNode, const char* pValue);
/**
 * Get the value of the node in a string Node.
 *
 * @param[in] hNode Handle to Node instance, should be a string node.
 * @param[out] value Value of the Node.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_StringGetValue(H_NODE hNode, char* value, size_t* pSize);
/**
 * Get the string maximum length of a string Node.
 *
 * @param[in] hNode Handle to Node instance, should be a string node.
 * @param[out] pMaxLength Maximum length of the Node value.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError NODE_StringGetMaxLength(H_NODE hNode, int64_t* pMaxLength);

#ifdef __cplusplus
}
}
#endif

#endif