
/***********************************************************************************
 *
 * ItalaApi - Copyright (C) 2023 Opto Engineering
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY SUFFERED BY LICENSE AS
 * A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 ***********************************************************************************/

#ifndef ITALA_API_C_TOCSTRING_H
#define ITALA_API_C_TOCSTRING_H

#include <stddef.h>
#include "ItalaApiC/Export.h"
#include "ItalaApiC/ItalaCDefs.h"
#ifdef __cplusplus
extern "C" {
namespace ItalaC {
#endif

/**
 * Converts a four-byte address to a readable string representation in
 * dotted-decimal format. This function is useful for displaying IP
 * addresses, gateways and subnet masks as well.
 *
 * @param[in] address The address to convert to string format.
 * @param[out] string Array of char, rappresenting the string converted.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError STR_AddressToString(uint32_t address, char* string, size_t* pSize);
/**
 * Converts a MAC address to a readable string representation in
 * colon-heaxadecimal format. This function is useful for displaying MAC addresses.
 *
 * @param[in] address The address to convert to string format.
 * @param[out] string Array of char, rappresenting the string converted.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError STR_MacAddressToString(uint64_t address, char* string, size_t* pSize);
/**
 * Converts an access status value to a readable string representation.
 *
 * @param[in] status The address to convert to string format.
 * @param[out] string Array of char, rappresenting the string converted.
 * @param[in, out] pSize Maximum element of the array in input, number of element filled in output.
 *
 * @return ItalaError the error code; return ItalaErrorSuccess (0) if no errors occures.
 */
ITALA_API_C ItalaError STR_AccessStatusToString(DeviceAccessStatus status, char* string,
                                                size_t* pSize);

#ifdef __cplusplus
}
}
#endif

#endif